<?php
/*
* 2007-2013 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2013 PrestaShop SA
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_'))
	exit;
require_once(dirname(__FILE__).'/classes/Configuration.php');
class Maintenance extends Module
{
	public $_html = '';
	public function __construct()
	{
		$this->name = 'maintenance';
		$this->tab = 'front_office_features';
		$this->version = '1.1';
		$this->author = 'Ittu Serk';
		$this->bootstrap = true;
		
		parent::__construct();
		$this->confirmUninstall = $this->l('Are you sure you want to uninstall this module?');
		$this->displayName = $this->l('Maintenance Mode');
		$this->description = $this->l('Display a custome page during maintenance mode.');
		$this->ps_versions_compliancy = array('min' => '1.5.6.1', 'max' => _PS_VERSION_);
		date_default_timezone_set('UTC');
	}

	public function install()
	{
		if(!parent::install()
		    || !$this->registerHook('displayMaintenance')
		    || !$this->registerHook('displayBackOfficeHeader')
		    || !$this->registerHook('backOfficeHeader')
		    || !$this->installDB())
			return false;
		return true;
	}

	public function uninstall()
	{
		if(!parent::uninstall()
		    || !Db::getInstance()->Execute("DROP TABLE `"._DB_PREFIX_."maintenance`"))
			return false;
		return true;
	}
	
	
	public function installDB(){
		/*  maintenance configuration table*/
		$configurationTable = "CREATE TABLE IF NOT EXISTS `"._DB_PREFIX_."maintenance` (
		`id` int(11) NOT NULL AUTO_INCREMENT,
		`next_time` datetime NOT NULL,
		`page_content` text NULL,
		`option_default_content` text NOT NULL,
		PRIMARY KEY (`id`)
		) ENGINE="._MYSQL_ENGINE_."  DEFAULT CHARSET=utf8";
		
		$firstInsertData = "INSERT INTO "._DB_PREFIX_."maintenance (`next_time`,`page_content`,`option_default_content`) VALUES ('".date('Y-m-d H:i:s')."','','1')";
		
		if(!Db::getInstance()->Execute($configurationTable) || !Db::getInstance()->Execute($firstInsertData))
			return false;
		return true;
	}

	public function getContent()
	{
		$configuration = new MaintenanceConfiguration();
		$html = '';
		if (Tools::isSubmit('savemaintenance'))
		{
			$next_time = date('Y-m-d H:i:s',strtotime(Tools::getValue('next_time')));
			$configuration->id = 1;
			$configuration->next_time = $next_time;
			$configuration->page_content = Tools::getValue('page_content');
			$configuration->option_default_content = (int)Tools::getValue('option_default_content');
			
			if ($configuration->validateFields(false))
			{
				$configuration->update();
				
				$this->context = Context::getContext();
				$this->context->cookie->flashmsg = '<div class="conf success">'.$this->l('Succesfully save the configuration').'</div>';
				Tools::redirectAdmin(AdminController::$currentIndex.'&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules'));
			}
			else
				$html .= '<div class="conf error">'.$this->l('An error occurred while attempting to save. Please try again.').'</div>';	
		}
		$data = MaintenanceConfiguration::getData();
		$helper = $this->initForm();
		$helper->fields_value['next_time'] = $data['next_time'];
		$helper->fields_value['page_content'] = $data['page_content'];
		$helper->fields_value['option_default_content'] = $data['option_default_content'];		
		return $html.$helper->generateForm($this->fields_form);
	}
	
	protected function initForm()
	{
		$default_lang = (int)Configuration::get('PS_LANG_DEFAULT');
		$this->fields_form[0]['form'] = array(
			'legend' => array(
				'title' => $this->l('Maintenance Mode'),
			),
			'input' => array(
				array(
					'type' => 'text',
					'readonly' => 'readonly',
					'label' => $this->l('Time:'),
					'name' => 'next_time',
					'value' => false,
					'desc' => $this->l('Set next time for your shop')
				),
				array(
					'type' => 'textarea',
					'label' => $this->l('Content'),
					'name' => 'page_content',
					'autoload_rte' => true,
					'hint' => $this->l('For example... show content in maintenance mode.'),
					'cols' => 60,
					'rows' => 30,
					'desc' => $this->l('Put the content of maintenance page.')
				),
				array(
					'type' => 'radio',
					'label' => $this->l('Default Content:'),
					'name' => 'option_default_content',
					'required' => false,
					'class' => 't',
					'is_bool' => true,
					'values' => array(
						array(
							'id' => 'active_on',
							'value' => 1,
							'label' => $this->l('Disable')
						),
						array(
							'id' => 'active_off',
							'value' => 0,
							'label' => $this->l('Enable')
						)
					),
					'desc' => $this->l('Enable or disable default content of Maintenance mode page.')
				),
			),
			'submit' => array(
				'title' => $this->l('Save'),
				'class' => 'button'
			)
		);
		$helper = new HelperForm();
		$helper->module = $this;
		$helper->name_controller = 'maintenance';
		$helper->identifier = $this->identifier;
		$helper->token = Tools::getAdminTokenLite('AdminModules');
		foreach (Language::getLanguages(false) as $lang)
			$helper->languages[] = array(
				'id_lang' => $lang['id_lang'],
				'iso_code' => $lang['iso_code'],
				'name' => $lang['name'],
				'is_default' => ($default_lang == $lang['id_lang'] ? 1 : 0)
			);
		$helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;
		$helper->default_form_language = $default_lang;
		$helper->allow_employee_form_lang = $default_lang;
		$helper->toolbar_scroll = true;
		$helper->title = $this->displayName;
		$helper->submit_action = 'savemaintenance';
		$helper->toolbar_btn =  array(
			'save' =>
			array(
				'desc' => $this->l('Save'),
				'href' => AdminController::$currentIndex.'&configure='.$this->name.'&save'.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules'),
			),
			'back' =>
			array(
				'href' => AdminController::$currentIndex.'&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules'),
				'desc' => $this->l('Back to list')
			)
		);
		return $helper;
	}
	
	public function hookDisplayMaintenance()
	{
		$config = MaintenanceConfiguration::getData();
		$next_time = strtotime($config['next_time']);
		$desired_date = date('d-m-Y H:i:s',$next_time);
		$today = strtotime(date('d-m-Y H:i:s'));
		$desired_date = strtotime($desired_date);
		
		if($desired_date > $today){
			$remain_time = $desired_date-$today;
		}else{
			$remain_time = 0;
		}
		
		$content = $config['page_content'];
		$option = $config['option_default_content'];
		
		$this->context->smarty->assign(array(
							'remain' => $remain_time,
							'option' => $option,
							'content' => $content,
							'iso_code' => $this->context->language->iso_code,
							'jsversion'=> _PS_JQUERY_VERSION_,
						   ));
		return $this->display(__FILE__,'views/templates/front/maintenance.tpl');
	}	

	public function hookBackOfficeHeader($params){
		$this->context->controller->addCss($this->_path . 'css/jquery.simple-dtpicker.css');
		$this->context->controller->addJquery();		
		$this->context->controller->addJs($this->_path . 'js/jquery.simple-dtpicker.js');
		$this->context->controller->addJs($this->_path . 'js/custom.js');
	}

	public function hookDisplayBackOfficeHeader($params){
		$this->hookBackOfficeHeader($params);
	}

}